# units

## Objects

 * <span class="badge object-type-scalar"></span> [Acres](./object-Acres.md)
 * <span class="badge object-type-scalar"></span> [Ampere](./object-Ampere.md)
 * <span class="badge object-type-scalar"></span> [AmpereHour](./object-AmpereHour.md)
 * <span class="badge object-type-scalar"></span> [ArcMinutes](./object-ArcMinutes.md)
 * <span class="badge object-type-scalar"></span> [ArcSeconds](./object-ArcSeconds.md)
 * <span class="badge object-type-scalar"></span> [Bars](./object-Bars.md)
 * <span class="badge object-type-scalar"></span> [Becquerel](./object-Becquerel.md)
 * <span class="badge object-type-scalar"></span> [Bictoin](./object-Bictoin.md)
 * <span class="badge object-type-scalar"></span> [BitsIEC](./object-BitsIEC.md)
 * <span class="badge object-type-scalar"></span> [BitsPerSecondIEC](./object-BitsPerSecondIEC.md)
 * <span class="badge object-type-scalar"></span> [BitsPerSecondSI](./object-BitsPerSecondSI.md)
 * <span class="badge object-type-scalar"></span> [BitsSI](./object-BitsSI.md)
 * <span class="badge object-type-scalar"></span> [Bool](./object-Bool.md)
 * <span class="badge object-type-scalar"></span> [BoolOnOff](./object-BoolOnOff.md)
 * <span class="badge object-type-scalar"></span> [BoolYesNo](./object-BoolYesNo.md)
 * <span class="badge object-type-scalar"></span> [BulgarianLev](./object-BulgarianLev.md)
 * <span class="badge object-type-scalar"></span> [BytesIEC](./object-BytesIEC.md)
 * <span class="badge object-type-scalar"></span> [BytesPerSecondIEC](./object-BytesPerSecondIEC.md)
 * <span class="badge object-type-scalar"></span> [BytesPerSecondSI](./object-BytesPerSecondSI.md)
 * <span class="badge object-type-scalar"></span> [BytesSI](./object-BytesSI.md)
 * <span class="badge object-type-scalar"></span> [CFPFranc](./object-CFPFranc.md)
 * <span class="badge object-type-scalar"></span> [Candela](./object-Candela.md)
 * <span class="badge object-type-scalar"></span> [Celsius](./object-Celsius.md)
 * <span class="badge object-type-scalar"></span> [ClockMilliseconds](./object-ClockMilliseconds.md)
 * <span class="badge object-type-scalar"></span> [ClockSeconds](./object-ClockSeconds.md)
 * <span class="badge object-type-scalar"></span> [CountsPerMinute](./object-CountsPerMinute.md)
 * <span class="badge object-type-scalar"></span> [CountsPerSecond](./object-CountsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [CubicDecimeter](./object-CubicDecimeter.md)
 * <span class="badge object-type-scalar"></span> [CubicFeetPerMinute](./object-CubicFeetPerMinute.md)
 * <span class="badge object-type-scalar"></span> [CubicFeetPerSecond](./object-CubicFeetPerSecond.md)
 * <span class="badge object-type-scalar"></span> [CubicMeter](./object-CubicMeter.md)
 * <span class="badge object-type-scalar"></span> [CubicMetersPerSecond](./object-CubicMetersPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Curie](./object-Curie.md)
 * <span class="badge object-type-scalar"></span> [CzechKoruna](./object-CzechKoruna.md)
 * <span class="badge object-type-scalar"></span> [DanishKrone](./object-DanishKrone.md)
 * <span class="badge object-type-scalar"></span> [DateTimeFromNow](./object-DateTimeFromNow.md)
 * <span class="badge object-type-scalar"></span> [DatetimeDefault](./object-DatetimeDefault.md)
 * <span class="badge object-type-scalar"></span> [DatetimeISO](./object-DatetimeISO.md)
 * <span class="badge object-type-scalar"></span> [DatetimeISONotToday](./object-DatetimeISONotToday.md)
 * <span class="badge object-type-scalar"></span> [DatetimeLocal](./object-DatetimeLocal.md)
 * <span class="badge object-type-scalar"></span> [DatetimeLocalNotToday](./object-DatetimeLocalNotToday.md)
 * <span class="badge object-type-scalar"></span> [DatetimeUS](./object-DatetimeUS.md)
 * <span class="badge object-type-scalar"></span> [DatetimeUSNotToday](./object-DatetimeUSNotToday.md)
 * <span class="badge object-type-scalar"></span> [Days](./object-Days.md)
 * <span class="badge object-type-scalar"></span> [Decibel](./object-Decibel.md)
 * <span class="badge object-type-scalar"></span> [DecibelMilliWatt](./object-DecibelMilliWatt.md)
 * <span class="badge object-type-scalar"></span> [Degrees](./object-Degrees.md)
 * <span class="badge object-type-scalar"></span> [DegreesPerSecond](./object-DegreesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Dollars](./object-Dollars.md)
 * <span class="badge object-type-scalar"></span> [DurationInDaysHoursMinutesSeconds](./object-DurationInDaysHoursMinutesSeconds.md)
 * <span class="badge object-type-scalar"></span> [DurationInHoursMinutesSeconds](./object-DurationInHoursMinutesSeconds.md)
 * <span class="badge object-type-scalar"></span> [DurationMilliseconds](./object-DurationMilliseconds.md)
 * <span class="badge object-type-scalar"></span> [DurationSeconds](./object-DurationSeconds.md)
 * <span class="badge object-type-scalar"></span> [ElectronVolt](./object-ElectronVolt.md)
 * <span class="badge object-type-scalar"></span> [Euro](./object-Euro.md)
 * <span class="badge object-type-scalar"></span> [EventsPerMinute](./object-EventsPerMinute.md)
 * <span class="badge object-type-scalar"></span> [EventsPerSecond](./object-EventsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [ExaFlopsPerSecond](./object-ExaFlopsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [ExaHashesPerSecond](./object-ExaHashesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Exposure](./object-Exposure.md)
 * <span class="badge object-type-scalar"></span> [Fahrenheit](./object-Fahrenheit.md)
 * <span class="badge object-type-scalar"></span> [Farad](./object-Farad.md)
 * <span class="badge object-type-scalar"></span> [Feet](./object-Feet.md)
 * <span class="badge object-type-scalar"></span> [FeetSecSquared](./object-FeetSecSquared.md)
 * <span class="badge object-type-scalar"></span> [FemtoFarad](./object-FemtoFarad.md)
 * <span class="badge object-type-scalar"></span> [FlopsPerSecond](./object-FlopsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [GUnit](./object-GUnit.md)
 * <span class="badge object-type-scalar"></span> [Gallons](./object-Gallons.md)
 * <span class="badge object-type-scalar"></span> [GallonsPerMinute](./object-GallonsPerMinute.md)
 * <span class="badge object-type-scalar"></span> [GibibitsPerSecond](./object-GibibitsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Gibibytes](./object-Gibibytes.md)
 * <span class="badge object-type-scalar"></span> [GibibytesPerSecond](./object-GibibytesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [GigaFlopsPerSecond](./object-GigaFlopsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [GigaHashesPerSecond](./object-GigaHashesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [GigaWatt](./object-GigaWatt.md)
 * <span class="badge object-type-scalar"></span> [GigabitsPerSecond](./object-GigabitsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Gigabytes](./object-Gigabytes.md)
 * <span class="badge object-type-scalar"></span> [GigabytesPerSecond](./object-GigabytesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [GigahertzRotation](./object-GigahertzRotation.md)
 * <span class="badge object-type-scalar"></span> [Gradian](./object-Gradian.md)
 * <span class="badge object-type-scalar"></span> [Gram](./object-Gram.md)
 * <span class="badge object-type-scalar"></span> [GramPerCubicMeter](./object-GramPerCubicMeter.md)
 * <span class="badge object-type-scalar"></span> [GramPerNormalCubicMeter](./object-GramPerNormalCubicMeter.md)
 * <span class="badge object-type-scalar"></span> [Gray](./object-Gray.md)
 * <span class="badge object-type-scalar"></span> [Guarani](./object-Guarani.md)
 * <span class="badge object-type-scalar"></span> [HashesPerSecond](./object-HashesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Hectares](./object-Hectares.md)
 * <span class="badge object-type-scalar"></span> [Hectopascals](./object-Hectopascals.md)
 * <span class="badge object-type-scalar"></span> [Henry](./object-Henry.md)
 * <span class="badge object-type-scalar"></span> [Hertz](./object-Hertz.md)
 * <span class="badge object-type-scalar"></span> [HertzRotation](./object-HertzRotation.md)
 * <span class="badge object-type-scalar"></span> [Hexadecimal](./object-Hexadecimal.md)
 * <span class="badge object-type-scalar"></span> [HexadecimalOx](./object-HexadecimalOx.md)
 * <span class="badge object-type-scalar"></span> [Hours](./object-Hours.md)
 * <span class="badge object-type-scalar"></span> [Hryvnias](./object-Hryvnias.md)
 * <span class="badge object-type-scalar"></span> [Humidity](./object-Humidity.md)
 * <span class="badge object-type-scalar"></span> [IOOpsPerSecond](./object-IOOpsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [IcelandicKrona](./object-IcelandicKrona.md)
 * <span class="badge object-type-scalar"></span> [Inch](./object-Inch.md)
 * <span class="badge object-type-scalar"></span> [InchesOfMercury](./object-InchesOfMercury.md)
 * <span class="badge object-type-scalar"></span> [IndianRupee](./object-IndianRupee.md)
 * <span class="badge object-type-scalar"></span> [IndonesianRupiah](./object-IndonesianRupiah.md)
 * <span class="badge object-type-scalar"></span> [IsraeliNewShekels](./object-IsraeliNewShekels.md)
 * <span class="badge object-type-scalar"></span> [Joule](./object-Joule.md)
 * <span class="badge object-type-scalar"></span> [Kelvin](./object-Kelvin.md)
 * <span class="badge object-type-scalar"></span> [KibibitsPerSecond](./object-KibibitsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Kibibytes](./object-Kibibytes.md)
 * <span class="badge object-type-scalar"></span> [KibibytesPerSecond](./object-KibibytesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [KiloAmpere](./object-KiloAmpere.md)
 * <span class="badge object-type-scalar"></span> [KiloAmpereHour](./object-KiloAmpereHour.md)
 * <span class="badge object-type-scalar"></span> [KiloHashesPerSecond](./object-KiloHashesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [KiloNewtonMeters](./object-KiloNewtonMeters.md)
 * <span class="badge object-type-scalar"></span> [KiloNewtons](./object-KiloNewtons.md)
 * <span class="badge object-type-scalar"></span> [KiloOhm](./object-KiloOhm.md)
 * <span class="badge object-type-scalar"></span> [KiloVolt](./object-KiloVolt.md)
 * <span class="badge object-type-scalar"></span> [KiloVoltAmpere](./object-KiloVoltAmpere.md)
 * <span class="badge object-type-scalar"></span> [KiloVoltAmpereReactive](./object-KiloVoltAmpereReactive.md)
 * <span class="badge object-type-scalar"></span> [KiloWatt](./object-KiloWatt.md)
 * <span class="badge object-type-scalar"></span> [KiloWattHour](./object-KiloWattHour.md)
 * <span class="badge object-type-scalar"></span> [KiloWattMinute](./object-KiloWattMinute.md)
 * <span class="badge object-type-scalar"></span> [Kilobars](./object-Kilobars.md)
 * <span class="badge object-type-scalar"></span> [KilobitsPerSecond](./object-KilobitsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Kilobytes](./object-Kilobytes.md)
 * <span class="badge object-type-scalar"></span> [KilobytesPerSecond](./object-KilobytesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Kilogram](./object-Kilogram.md)
 * <span class="badge object-type-scalar"></span> [KilohertzRotation](./object-KilohertzRotation.md)
 * <span class="badge object-type-scalar"></span> [Kilometer](./object-Kilometer.md)
 * <span class="badge object-type-scalar"></span> [KilometersPerHour](./object-KilometersPerHour.md)
 * <span class="badge object-type-scalar"></span> [Kilopascals](./object-Kilopascals.md)
 * <span class="badge object-type-scalar"></span> [Knot](./object-Knot.md)
 * <span class="badge object-type-scalar"></span> [Litre](./object-Litre.md)
 * <span class="badge object-type-scalar"></span> [LitrePerHour](./object-LitrePerHour.md)
 * <span class="badge object-type-scalar"></span> [LitrePerMinute](./object-LitrePerMinute.md)
 * <span class="badge object-type-scalar"></span> [LocaleFormat](./object-LocaleFormat.md)
 * <span class="badge object-type-scalar"></span> [Lumens](./object-Lumens.md)
 * <span class="badge object-type-scalar"></span> [Lux](./object-Lux.md)
 * <span class="badge object-type-scalar"></span> [MalaysianRinggit](./object-MalaysianRinggit.md)
 * <span class="badge object-type-scalar"></span> [MebibitsPerSecond](./object-MebibitsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Mebibytes](./object-Mebibytes.md)
 * <span class="badge object-type-scalar"></span> [MebibytesPerSecond](./object-MebibytesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [MegaFlopsPerSecond](./object-MegaFlopsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [MegaHashesPerSecond](./object-MegaHashesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [MegaOhm](./object-MegaOhm.md)
 * <span class="badge object-type-scalar"></span> [MegaWatt](./object-MegaWatt.md)
 * <span class="badge object-type-scalar"></span> [MegaWattHour](./object-MegaWattHour.md)
 * <span class="badge object-type-scalar"></span> [MegabitsPerSecond](./object-MegabitsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Megabytes](./object-Megabytes.md)
 * <span class="badge object-type-scalar"></span> [MegabytesPerSecond](./object-MegabytesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [MegahertzRotation](./object-MegahertzRotation.md)
 * <span class="badge object-type-scalar"></span> [MessagesPerMinute](./object-MessagesPerMinute.md)
 * <span class="badge object-type-scalar"></span> [MessagesPerSecond](./object-MessagesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Meter](./object-Meter.md)
 * <span class="badge object-type-scalar"></span> [MetersPerSecond](./object-MetersPerSecond.md)
 * <span class="badge object-type-scalar"></span> [MetersSecSquared](./object-MetersSecSquared.md)
 * <span class="badge object-type-scalar"></span> [MetricTon](./object-MetricTon.md)
 * <span class="badge object-type-scalar"></span> [MicroBitcoin](./object-MicroBitcoin.md)
 * <span class="badge object-type-scalar"></span> [MicroFarad](./object-MicroFarad.md)
 * <span class="badge object-type-scalar"></span> [MicroHenry](./object-MicroHenry.md)
 * <span class="badge object-type-scalar"></span> [MicrogramPerCubicMeter](./object-MicrogramPerCubicMeter.md)
 * <span class="badge object-type-scalar"></span> [MicrogramPerNormalCubicMeter](./object-MicrogramPerNormalCubicMeter.md)
 * <span class="badge object-type-scalar"></span> [Microseconds](./object-Microseconds.md)
 * <span class="badge object-type-scalar"></span> [Microsievert](./object-Microsievert.md)
 * <span class="badge object-type-scalar"></span> [MicrosievertPerHour](./object-MicrosievertPerHour.md)
 * <span class="badge object-type-scalar"></span> [Mile](./object-Mile.md)
 * <span class="badge object-type-scalar"></span> [MilesPerHour](./object-MilesPerHour.md)
 * <span class="badge object-type-scalar"></span> [MilliAmpere](./object-MilliAmpere.md)
 * <span class="badge object-type-scalar"></span> [MilliAmpereHour](./object-MilliAmpereHour.md)
 * <span class="badge object-type-scalar"></span> [MilliBitcoin](./object-MilliBitcoin.md)
 * <span class="badge object-type-scalar"></span> [MilliHenry](./object-MilliHenry.md)
 * <span class="badge object-type-scalar"></span> [MilliLitrePerMinute](./object-MilliLitrePerMinute.md)
 * <span class="badge object-type-scalar"></span> [MilliOhm](./object-MilliOhm.md)
 * <span class="badge object-type-scalar"></span> [MilliVolt](./object-MilliVolt.md)
 * <span class="badge object-type-scalar"></span> [MilliWatt](./object-MilliWatt.md)
 * <span class="badge object-type-scalar"></span> [Millibars](./object-Millibars.md)
 * <span class="badge object-type-scalar"></span> [Milligram](./object-Milligram.md)
 * <span class="badge object-type-scalar"></span> [MilligramPerCubicMeter](./object-MilligramPerCubicMeter.md)
 * <span class="badge object-type-scalar"></span> [MilligramPerNormalCubicMeter](./object-MilligramPerNormalCubicMeter.md)
 * <span class="badge object-type-scalar"></span> [MilligramsPerDecilitre](./object-MilligramsPerDecilitre.md)
 * <span class="badge object-type-scalar"></span> [Millilitre](./object-Millilitre.md)
 * <span class="badge object-type-scalar"></span> [Millimeter](./object-Millimeter.md)
 * <span class="badge object-type-scalar"></span> [MillimolesPerLiter](./object-MillimolesPerLiter.md)
 * <span class="badge object-type-scalar"></span> [Milliseconds](./object-Milliseconds.md)
 * <span class="badge object-type-scalar"></span> [Millisievert](./object-Millisievert.md)
 * <span class="badge object-type-scalar"></span> [MillisievertPerHour](./object-MillisievertPerHour.md)
 * <span class="badge object-type-scalar"></span> [Minutes](./object-Minutes.md)
 * <span class="badge object-type-scalar"></span> [NanoFarad](./object-NanoFarad.md)
 * <span class="badge object-type-scalar"></span> [NanogramPerCubicMeter](./object-NanogramPerCubicMeter.md)
 * <span class="badge object-type-scalar"></span> [NanogramPerNormalCubicMeter](./object-NanogramPerNormalCubicMeter.md)
 * <span class="badge object-type-scalar"></span> [Nanoseconds](./object-Nanoseconds.md)
 * <span class="badge object-type-scalar"></span> [NewtonMeters](./object-NewtonMeters.md)
 * <span class="badge object-type-scalar"></span> [Newtons](./object-Newtons.md)
 * <span class="badge object-type-scalar"></span> [NoUnit](./object-NoUnit.md)
 * <span class="badge object-type-scalar"></span> [NormalCubicMeter](./object-NormalCubicMeter.md)
 * <span class="badge object-type-scalar"></span> [NorwegianKrone](./object-NorwegianKrone.md)
 * <span class="badge object-type-scalar"></span> [Number](./object-Number.md)
 * <span class="badge object-type-scalar"></span> [Ohm](./object-Ohm.md)
 * <span class="badge object-type-scalar"></span> [OpsPerMinute](./object-OpsPerMinute.md)
 * <span class="badge object-type-scalar"></span> [OpsPerSecond](./object-OpsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [PSI](./object-PSI.md)
 * <span class="badge object-type-scalar"></span> [PacketsPerSecond](./object-PacketsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [PartsPerBillion](./object-PartsPerBillion.md)
 * <span class="badge object-type-scalar"></span> [PartsPerMillion](./object-PartsPerMillion.md)
 * <span class="badge object-type-scalar"></span> [Pascals](./object-Pascals.md)
 * <span class="badge object-type-scalar"></span> [PebibitsPerSecond](./object-PebibitsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Pebibytes](./object-Pebibytes.md)
 * <span class="badge object-type-scalar"></span> [PebibytesPerSecond](./object-PebibytesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Percent](./object-Percent.md)
 * <span class="badge object-type-scalar"></span> [PercentUnit](./object-PercentUnit.md)
 * <span class="badge object-type-scalar"></span> [PetaFlopsPerSecond](./object-PetaFlopsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [PetaHashesPerSecond](./object-PetaHashesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [PetabitsPerSecond](./object-PetabitsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Petabytes](./object-Petabytes.md)
 * <span class="badge object-type-scalar"></span> [PetabytesPerSecond](./object-PetabytesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [PhilippinePeso](./object-PhilippinePeso.md)
 * <span class="badge object-type-scalar"></span> [PicoFarad](./object-PicoFarad.md)
 * <span class="badge object-type-scalar"></span> [Pixels](./object-Pixels.md)
 * <span class="badge object-type-scalar"></span> [PolishZloty](./object-PolishZloty.md)
 * <span class="badge object-type-scalar"></span> [Pound](./object-Pound.md)
 * <span class="badge object-type-scalar"></span> [Pounds](./object-Pounds.md)
 * <span class="badge object-type-scalar"></span> [Rad](./object-Rad.md)
 * <span class="badge object-type-scalar"></span> [Radians](./object-Radians.md)
 * <span class="badge object-type-scalar"></span> [RadiansPerSecond](./object-RadiansPerSecond.md)
 * <span class="badge object-type-scalar"></span> [ReadsPerMinute](./object-ReadsPerMinute.md)
 * <span class="badge object-type-scalar"></span> [ReadsPerSecond](./object-ReadsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Real](./object-Real.md)
 * <span class="badge object-type-scalar"></span> [RecordsPerMinute](./object-RecordsPerMinute.md)
 * <span class="badge object-type-scalar"></span> [RecordsPerSecond](./object-RecordsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Rem](./object-Rem.md)
 * <span class="badge object-type-scalar"></span> [RequestsPerMinute](./object-RequestsPerMinute.md)
 * <span class="badge object-type-scalar"></span> [RequestsPerSecond](./object-RequestsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [RevolutionsPerMinute](./object-RevolutionsPerMinute.md)
 * <span class="badge object-type-scalar"></span> [Roentgen](./object-Roentgen.md)
 * <span class="badge object-type-scalar"></span> [RowsPerMinute](./object-RowsPerMinute.md)
 * <span class="badge object-type-scalar"></span> [RowsPerSecond](./object-RowsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Rubles](./object-Rubles.md)
 * <span class="badge object-type-scalar"></span> [ScientificNotation](./object-ScientificNotation.md)
 * <span class="badge object-type-scalar"></span> [Seconds](./object-Seconds.md)
 * <span class="badge object-type-scalar"></span> [Short](./object-Short.md)
 * <span class="badge object-type-scalar"></span> [SiShort](./object-SiShort.md)
 * <span class="badge object-type-scalar"></span> [Sievert](./object-Sievert.md)
 * <span class="badge object-type-scalar"></span> [SievertPerHour](./object-SievertPerHour.md)
 * <span class="badge object-type-scalar"></span> [SouthAfricanRand](./object-SouthAfricanRand.md)
 * <span class="badge object-type-scalar"></span> [SouthKoreanWon](./object-SouthKoreanWon.md)
 * <span class="badge object-type-scalar"></span> [SquareFeet](./object-SquareFeet.md)
 * <span class="badge object-type-scalar"></span> [SquareMeters](./object-SquareMeters.md)
 * <span class="badge object-type-scalar"></span> [SquareMiles](./object-SquareMiles.md)
 * <span class="badge object-type-scalar"></span> [String](./object-String.md)
 * <span class="badge object-type-scalar"></span> [SwedishKrona](./object-SwedishKrona.md)
 * <span class="badge object-type-scalar"></span> [SwissFranc](./object-SwissFranc.md)
 * <span class="badge object-type-scalar"></span> [TebibitsPerSecond](./object-TebibitsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Tebibytes](./object-Tebibytes.md)
 * <span class="badge object-type-scalar"></span> [TebibytesPerSecond](./object-TebibytesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [TeraFlopsPerSecond](./object-TeraFlopsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [TeraHashesPerSecond](./object-TeraHashesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [TerabitsPerSecond](./object-TerabitsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Terabytes](./object-Terabytes.md)
 * <span class="badge object-type-scalar"></span> [TerabytesPerSecond](./object-TerabytesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Timeticks](./object-Timeticks.md)
 * <span class="badge object-type-scalar"></span> [TurkishLira](./object-TurkishLira.md)
 * <span class="badge object-type-scalar"></span> [UruguayPeso](./object-UruguayPeso.md)
 * <span class="badge object-type-scalar"></span> [VietnameseDong](./object-VietnameseDong.md)
 * <span class="badge object-type-scalar"></span> [Volt](./object-Volt.md)
 * <span class="badge object-type-scalar"></span> [VoltAmpere](./object-VoltAmpere.md)
 * <span class="badge object-type-scalar"></span> [VoltAmpereReactive](./object-VoltAmpereReactive.md)
 * <span class="badge object-type-scalar"></span> [Watt](./object-Watt.md)
 * <span class="badge object-type-scalar"></span> [WattHour](./object-WattHour.md)
 * <span class="badge object-type-scalar"></span> [WattHourPerKilogram](./object-WattHourPerKilogram.md)
 * <span class="badge object-type-scalar"></span> [WattPerSquareMeter](./object-WattPerSquareMeter.md)
 * <span class="badge object-type-scalar"></span> [WritesPerMinute](./object-WritesPerMinute.md)
 * <span class="badge object-type-scalar"></span> [WritesPerSecond](./object-WritesPerSecond.md)
 * <span class="badge object-type-scalar"></span> [Yen](./object-Yen.md)
 * <span class="badge object-type-scalar"></span> [YottaFlopsPerSecond](./object-YottaFlopsPerSecond.md)
 * <span class="badge object-type-scalar"></span> [ZettaFlopsPerSecond](./object-ZettaFlopsPerSecond.md)
## Builders

